==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/message/impl/InformalSynchronousMessageSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.message.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.message.InformalSynchronousMessage;
import io.ciera.tool.sql.ooaofooa.message.InformalSynchronousMessageSet;
import io.ciera.tool.sql.ooaofooa.message.SynchronousMessageSet;
import io.ciera.tool.sql.ooaofooa.message.impl.SynchronousMessageSetImpl;

import java.util.Arrays;
import java.util.List;


public class InformalSynchronousMessageSetImpl extends InstanceSet<InformalSynchronousMessageSet,InformalSynchronousMessage> implements InformalSynchronousMessageSet {

    // attributes
    @Override
    public void setMsg_ID( UniqueId ref_Msg_ID ) throws XtumlException {
        for ( InformalSynchronousMessage informalsynchronousmessage : this ) informalsynchronousmessage.setMsg_ID( ref_Msg_ID );
    }


    // selections
    @Override
    public SynchronousMessageSet R1020_is_a_SynchronousMessage() throws XtumlException {
        SynchronousMessageSet synchronousmessageset = new SynchronousMessageSetImpl();
        for ( InformalSynchronousMessage informalsynchronousmessage : this ) synchronousmessageset.add( informalsynchronousmessage.R1020_is_a_SynchronousMessage() );
        return synchronousmessageset;
    }


    @Override
    public InformalSynchronousMessage nullElement() {
        return InformalSynchronousMessageImpl.EMPTY_INFORMALSYNCHRONOUSMESSAGE;
    }

    @Override
    public InformalSynchronousMessageSet emptySet() {
      return new InformalSynchronousMessageSetImpl();
    }

    @Override
    public InformalSynchronousMessageSet value() {
        return this;
    }

    @Override
    public List<InformalSynchronousMessage> elements() {
        return Arrays.asList(toArray(new InformalSynchronousMessage[0]));
    }

}

==> tool-sql-2.2.0-sources.jar: io/ciera/tool/sql/ooaofooa/message/impl/InformalSynchronousMessageSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.message.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.message.InformalSynchronousMessage;
import io.ciera.tool.sql.ooaofooa.message.InformalSynchronousMessageSet;
import io.ciera.tool.sql.ooaofooa.message.SynchronousMessageSet;
import io.ciera.tool.sql.ooaofooa.message.impl.SynchronousMessageSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class InformalSynchronousMessageSetImpl extends InstanceSet<InformalSynchronousMessageSet,InformalSynchronousMessage> implements InformalSynchronousMessageSet {

    public InformalSynchronousMessageSetImpl() {
    }

    public InformalSynchronousMessageSetImpl(Comparator<? super InformalSynchronousMessage> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setMsg_ID( UniqueId ref_Msg_ID ) throws XtumlException {
        for ( InformalSynchronousMessage informalsynchronousmessage : this ) informalsynchronousmessage.setMsg_ID( ref_Msg_ID );
    }


    // selections
    @Override
    public SynchronousMessageSet R1020_is_a_SynchronousMessage() throws XtumlException {
        SynchronousMessageSet synchronousmessageset = new SynchronousMessageSetImpl();
        for ( InformalSynchronousMessage informalsynchronousmessage : this ) synchronousmessageset.add( informalsynchronousmessage.R1020_is_a_SynchronousMessage() );
        return synchronousmessageset;
    }


    @Override
    public InformalSynchronousMessage nullElement() {
        return InformalSynchronousMessageImpl.EMPTY_INFORMALSYNCHRONOUSMESSAGE;
    }

    @Override
    public InformalSynchronousMessageSet emptySet() {
      return new InformalSynchronousMessageSetImpl();
    }

    @Override
    public InformalSynchronousMessageSet emptySet(Comparator<? super InformalSynchronousMessage> comp) {
      return new InformalSynchronousMessageSetImpl(comp);
    }

    @Override
    public InformalSynchronousMessageSet value() {
        return this;
    }

    @Override
    public List<InformalSynchronousMessage> elements() {
        return Arrays.asList(toArray(new InformalSynchronousMessage[0]));
    }

}
